@@ -23,16 +23,15 @@
 
 #include "chat-search-bar.h"
 #include "chat-tab.h"
-#include "chat-widget.h"
 
 #include <KTp/service-availability-checker.h>
 #include <KTp/actions.h>
 #include <KTp/contact.h>
 
+#include <KActionMenu>
 #include <KStandardAction>
 #include <KLocalizedString>
 #include <KActionCollection>
-#include <KColorScheme>
 #include <ksettings/dialog.h>
 #include <kcmodulecontainer.h>
 #include <KNotification>
@@ -42,7 +41,7 @@
 #include <KCModuleProxy>
 #include <KIconLoader>
 
-#include <QApplication>
+#include <QCoreApplication>
 #include <QFileDialog>
 #include <QUrl>
 #include <QMenu>
@@ -54,6 +53,7 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QMouseEvent>
+#include <QScrollArea>
 
 #include <TelepathyQt/Account>
 #include <TelepathyQt/ContactCapabilities>
@@ -761,7 +761,9 @@ void ChatWindow::showSettingsDialog()
     KSettings::Dialog *dialog = new KSettings::Dialog(this);
 
     KPageWidgetItem *configPage = dialog->addModule(QLatin1String("kcm_ktp_chat_appearance"));
-    KCModuleProxy *proxy = qobject_cast<KCModuleProxy*>(configPage->widget());
+    QScrollArea *moduleScroll = qobject_cast<QScrollArea*>(configPage->widget());
+    Q_ASSERT(moduleScroll);
+    KCModuleProxy *proxy = qobject_cast<KCModuleProxy*>(moduleScroll->widget());
     Q_ASSERT(proxy);
 
     connect(proxy->realModule(), SIGNAL(reloadTheme()),
@@ -771,7 +773,9 @@ void ChatWindow::showSettingsDialog()
     dialog->addModule(QLatin1String("kcm_ktp_chat_messages"));
 
     KPageWidgetItem *otrConfigPage = dialog->addModule(QLatin1String("kcm_ktp_chat_otr"));
-    proxy = qobject_cast<KCModuleProxy*>(otrConfigPage->widget());
+    moduleScroll = qobject_cast<QScrollArea*>(otrConfigPage->widget());
+    Q_ASSERT(moduleScroll);
+    proxy = qobject_cast<KCModuleProxy*>(moduleScroll->widget());
     Q_ASSERT(proxy);
     QVariant value;
     value.setValue(m_proxyService);
